@@ -1,6 +1,6 @@
 package Form::Toolkit::Form;
 {
-  $Form::Toolkit::Form::VERSION = '0.004';
+  $Form::Toolkit::Form::VERSION = '0.005';
 }
 require 5.010_000;
 use Moose -traits => 'Form::Toolkit::Meta::Class::Trait::HasID';
@@ -310,7 +310,7 @@ sub values_hash{
   return $ret;
 }
 
-=head2 litteral
+=head2 literal
 
 Returns a litteral representation of this form (as a Base64 encoded JSON byte string).
 
@@ -320,12 +320,12 @@ Usage:
 
 =cut
 
-sub litteral{
+sub literal{
   my ($self) = @_;
   return MIME::Base64::encode_base64url(ref($self) .'|'. $self->jsoner()->encode($self->values_hash()));
 }
 
-=head2 from_litteral
+=head2 from_literal
 
 Class or instance method. Builds a new instance of form from the given litteral (See litteral).
 
@@ -335,11 +335,11 @@ as an instance method by the form filling Clerks. See example in test 11.
 
 Usage:
 
-  my $form = $this->from_litteral($litteral);
+  my $form = $this->from_literal($litteral);
 
 =cut
 
-sub from_litteral{
+sub from_literal{
   my ($class , $litteral, $attributes ) = @_;
   $attributes ||= {};
   my ($fclass, $json) = split('\|', MIME::Base64::decode_base64url($litteral) , 2 );
